package com.ims.eval.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ims.common.utils.StringUtils;
import com.ims.eval.entity.EvaluateRule;
import com.ims.eval.dao.EvaluateRuleMapper;
import com.ims.eval.entity.Indicator;
import com.ims.eval.service.IEvaluateRuleService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 考评规则表 服务实现类
 * </p>
 *
 * @author wang
 * @since 2023-02-27
 */
@Service
public class EvaluateRuleServiceImpl extends ServiceImpl<EvaluateRuleMapper, EvaluateRule> implements IEvaluateRuleService {

	@Override
	public IPage<EvaluateRule> list(Integer pageNum, Integer pageSize, String id, String des, String indicatorId, String evaluateMethod) {

		QueryWrapper<EvaluateRule> qw = new QueryWrapper<>();
		if (null == pageNum || null == pageSize) {
			throw new RuntimeException("分页参数为空");
		}
		//构造分页构造器
		Page<EvaluateRule> page = new Page<>(pageNum, pageSize);


		if (StringUtils.isNotEmpty(id)) {
			qw.lambda().eq(EvaluateRule::getId, id);
		}

		if (StringUtils.isNotEmpty(des)) {
			qw.lambda().like(EvaluateRule::getDes, des);
		}

		if (StringUtils.isNotEmpty(indicatorId)) {
			qw.lambda().like(EvaluateRule::getIndicatorId, indicatorId);
		}

		if (StringUtils.isNotEmpty(evaluateMethod)) {
			qw.lambda().eq(EvaluateRule::getEvaluateMethod, evaluateMethod);
		}

		qw.lambda().orderByAsc(EvaluateRule::getId);

		IPage<EvaluateRule> list = baseMapper.selectPage(page, qw);

		return list;
	}

	@Override
	public boolean saveOrUpdate(EvaluateRule entity) {

		if (null != entity && (null == entity.getId() || "".equals(entity.getId().trim()))) {
			QueryWrapper<EvaluateRule> qw = new QueryWrapper<>();
			qw.lambda().eq(EvaluateRule::getIndicatorId, entity.getIndicatorId());
			List<EvaluateRule> list = baseMapper.selectList(qw);
			if (null != list && list.size() > 0) {
				throw new RuntimeException("当前指标评分规则已存在");
			}
			entity.setUpdateTime(new Date());
		} else {
			entity.setCreateTime(new Date());
		}
		return super.saveOrUpdate(entity);

	}
}
